# Modeling SAP S/4HANA
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana#introduction)
  * [SAP S/4HANA Modeling Best Practices and Guidelines](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana#sap-s/4hana-modeling-best-practices-and-guidelines)
  * [On-Premise Deployment](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana#on-premise-deployment)
  * [Cloud Deployment](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana#cloud-deployment)
  * [Hybrid Deployment](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana#hybrid-deployment)
  * [Modeling Fiori Applications as Part of the S4/HANA Tech Stack](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana#modeling-fiori-applications-as-part-of-the-s4/hana-tech-stack)


Understand the SAP S/4HANA application structure and the key difference between modeling the S/4HANA stack and the classic SAP ERP stack, and learn how to model S/4HANA in SAP LeanIX.
